@@ -30,13 +30,21 @@ def rollout(env,
 
     Returns:
         dict[str, np.ndarray or dict]: Dictionary, with keys:
-            * observations(np.array): Non-flattened array of observations.
-            * actions(np.array): Non-flattened array of actions.
-            * rewards(np.array): Array of rewards of shape (timesteps, 1).
-            * agent_infos(dict[str, np.ndarray]): Dictionary of stacked,
-                  non-flattened `agent_info`s.
-            * env_infos(dict[str, np.ndarray]): Dictionary of stacked,
-                  non-flattened `env_info`s.
+            * observations(np.array): Flattened array of observations.
+                There should be one more of these than actions. Note that
+                observations[i] (for i < len(observations) - 1) was used by the
+                agent to choose actions[i]. Should have shape (T + 1, S^*) (the
+                unflattened state space of the current environment).
+            * actions(np.array): Non-flattened array of actions. Should have
+                shape (T, S^*) (the unflattened action space of the current
+                environment).
+            * rewards(np.array): Array of rewards of shape (T,) (1D array of
+                length timesteps).
+            * agent_infos(Dict[str, np.array]): Dictionary of stacked,
+                non-flattened `agent_info` arrays.
+            * env_infos(Dict[str, np.array]): Dictionary of stacked,
+                non-flattened `env_info` arrays.
+            * dones(np.array): Array of termination signals.
 
     """
     observations = []
@@ -44,12 +52,14 @@ def rollout(env,
     rewards = []
     agent_infos = []
     env_infos = []
+    dones = []
     o = env.reset()
     agent.reset()
     path_length = 0
     if animated:
         env.render()
-    while path_length < max_path_length:
+    while path_length < (max_path_length or np.inf):
+        o = env.observation_space.flatten(o)
         a, agent_info = agent.get_action(o)
         if deterministic and 'mean' in agent_info:
             a = agent_info['mean']
@@ -59,6 +69,7 @@ def rollout(env,
         actions.append(a)
         agent_infos.append(agent_info)
         env_infos.append(env_info)
+        dones.append(d)
         path_length += 1
         if d:
             break
@@ -74,6 +85,7 @@ def rollout(env,
         rewards=np.array(rewards),
         agent_infos=tensor_utils.stack_tensor_dict_list(agent_infos),
         env_infos=tensor_utils.stack_tensor_dict_list(env_infos),
+        dones=np.array(dones),
     )
 
 
