@@ -1,15 +1,22 @@
-"""GaussianLSTMModel."""
+"""Gaussian LSTM Model.
+
+A model represented by a Gaussian distribution
+which is parameterized by a Long short-term memory (LSTM).
+"""
 import numpy as np
 import tensorflow as tf
+import tensorflow_probability as tfp
 
-from garage.tf.distributions import DiagonalGaussian
-from garage.tf.models import Model
 from garage.tf.models.lstm import lstm
+from garage.tf.models.model import Model
 from garage.tf.models.parameter import recurrent_parameter
 
 
 class GaussianLSTMModel(Model):
-    """GaussianLSTMModel.
+    """Gaussian LSTM Model.
+
+    A model represented by a Gaussian distribution
+    which is parameterized by a Long short-term memory (LSTM).
 
     Args:
         output_dim (int): Output dimension of the model.
@@ -55,6 +62,7 @@ class GaussianLSTMModel(Model):
         std_share_network (bool): Boolean for whether mean and std share
             the same network.
         layer_normalization (bool): Bool for using layer normalization or not.
+
     """
 
     def __init__(self,
@@ -62,12 +70,12 @@ class GaussianLSTMModel(Model):
                  hidden_dim=32,
                  name=None,
                  hidden_nonlinearity=tf.nn.tanh,
-                 hidden_w_init=tf.glorot_uniform_initializer(),
+                 hidden_w_init=tf.initializers.glorot_uniform(),
                  hidden_b_init=tf.zeros_initializer(),
                  recurrent_nonlinearity=tf.nn.sigmoid,
-                 recurrent_w_init=tf.glorot_uniform_initializer(),
+                 recurrent_w_init=tf.initializers.glorot_uniform(),
                  output_nonlinearity=None,
-                 output_w_init=tf.glorot_uniform_initializer(),
+                 output_w_init=tf.initializers.glorot_uniform(),
                  output_b_init=tf.zeros_initializer(),
                  hidden_state_init=tf.zeros_initializer(),
                  hidden_state_init_trainable=False,
@@ -97,6 +105,7 @@ class GaussianLSTMModel(Model):
         self._layer_normalization = layer_normalization
         self._learn_std = learn_std
         self._std_share_network = std_share_network
+        # pylint: disable=assignment-from-no-return
         self._init_std_param = np.log(init_std)
         self._initialize()
 
@@ -134,24 +143,61 @@ class GaussianLSTMModel(Model):
             name='mean_output_layer')
 
     def network_input_spec(self):
-        """Network input spec."""
+        """Network input spec.
+
+        Returns:
+            list[str]: Name of the model inputs, in order.
+
+        """
         return [
             'full_input', 'step_input', 'step_hidden_input', 'step_cell_input'
         ]
 
     def network_output_spec(self):
-        """Network output spec."""
+        """Network output spec.
+
+        Returns:
+            list[str]: Name of the model outputs, in order.
+
+        """
         return [
-            'mean', 'step_mean', 'log_std', 'step_log_std', 'step_hidden',
-            'step_cell', 'init_hidden', 'init_cell', 'dist'
+            'dist', 'step_mean', 'step_log_std', 'step_hidden', 'step_cell',
+            'init_hidden', 'init_cell'
         ]
 
+    # pylint: disable=arguments-differ
     def _build(self,
                state_input,
                step_input,
-               hidden_input,
-               cell_input,
+               step_hidden,
+               step_cell,
                name=None):
+        """Build model.
+
+        Args:
+            state_input (tf.Tensor): Entire time-series observation input,
+                with shape :math:`(N, T, S^*)`.
+            step_input (tf.Tensor): Single timestep observation input,
+                with shape :math:`(N, S^*)`.
+            step_hidden (tf.Tensor): Hidden state for step, with shape
+                :math:`(N, S^*)`.
+            step_cell (tf.Tensor): Cell state for step, with shape
+                :math:`(N, S^*)`.
+            name (str): Inner model name, also the variable scope of the
+                inner model, if exist. One example is
+                garage.tf.models.Sequential.
+
+        Returns:
+            tfp.distributions.MultivariateNormalDiag: Policy distribution.
+            tf.Tensor: Step means, with shape :math:`(N, S^*)`.
+            tf.Tensor: Step log std, with shape :math:`(N, S^*)`.
+            tf.Tensor: Step hidden state, with shape :math:`(N, S^*)`.
+            tf.Tensor: Step cell state, with shape :math:`(N, S^*)`.
+            tf.Tensor: Initial hidden state, with shape :math:`(S^*)`.
+            tf.Tensor: Initial cell state, with shape :math:`(S^*)`
+
+        """
+        del name
         action_dim = self._output_dim
 
         with tf.compat.v1.variable_scope('dist_params'):
@@ -163,8 +209,8 @@ class GaussianLSTMModel(Model):
                      lstm_cell=self._mean_std_lstm_cell,
                      all_input_var=state_input,
                      step_input_var=step_input,
-                     step_hidden_var=hidden_input,
-                     step_cell_var=cell_input,
+                     step_hidden_var=step_hidden,
+                     step_cell_var=step_cell,
                      hidden_state_init=self._hidden_state_init,
                      hidden_state_init_trainable=self.
                      _hidden_state_init_trainable,
@@ -188,8 +234,8 @@ class GaussianLSTMModel(Model):
                      lstm_cell=self._mean_lstm_cell,
                      all_input_var=state_input,
                      step_input_var=step_input,
-                     step_hidden_var=hidden_input,
-                     step_cell_var=cell_input,
+                     step_hidden_var=step_hidden,
+                     step_cell_var=step_cell,
                      hidden_state_init=self._hidden_state_init,
                      hidden_state_init_trainable=self.
                      _hidden_state_init_trainable,
@@ -205,13 +251,19 @@ class GaussianLSTMModel(Model):
                     trainable=self._learn_std,
                     name='log_std_param')
 
-        dist = DiagonalGaussian(self._output_dim)
+        dist = tfp.distributions.MultivariateNormalDiag(
+            loc=mean_var, scale_diag=tf.exp(log_std_var))
 
-        return (mean_var, step_mean_var, log_std_var, step_log_std_var,
-                step_hidden, step_cell, hidden_init_var, cell_init_var, dist)
+        return (dist, step_mean_var, step_log_std_var, step_hidden, step_cell,
+                hidden_init_var, cell_init_var)
 
     def __getstate__(self):
-        """Object.__getstate__."""
+        """Object.__getstate__.
+
+        Returns:
+            dict: the state to be pickled for the instance.
+
+        """
         new_dict = super().__getstate__()
         del new_dict['_mean_std_lstm_cell']
         del new_dict['_mean_lstm_cell']
@@ -220,6 +272,11 @@ class GaussianLSTMModel(Model):
         return new_dict
 
     def __setstate__(self, state):
-        """Object.__setstate__."""
+        """Object.__setstate__.
+
+        Args:
+            state (dict): unpickled state.
+
+        """
         super().__setstate__(state)
         self._initialize()
