@@ -7,7 +7,7 @@ continuous action.
 import tensorflow as tf
 
 from garage.tf.models import MLPModel
-from garage.tf.policies import Policy
+from garage.tf.policies.policy import Policy
 
 
 class ContinuousMLPPolicy(Policy):
@@ -40,7 +40,6 @@ class ContinuousMLPPolicy(Policy):
         output_b_init (callable): Initializer function for the bias
             of output dense layer(s). The function should return a
             tf.Tensor.
-        input_include_goal (bool): Include goal in the observation or not.
         layer_normalization (bool): Bool for using layer normalization or not.
 
     """
@@ -50,12 +49,11 @@ class ContinuousMLPPolicy(Policy):
                  name='ContinuousMLPPolicy',
                  hidden_sizes=(64, 64),
                  hidden_nonlinearity=tf.nn.relu,
-                 hidden_w_init=tf.glorot_uniform_initializer(),
+                 hidden_w_init=tf.initializers.glorot_uniform(),
                  hidden_b_init=tf.zeros_initializer(),
                  output_nonlinearity=tf.nn.tanh,
-                 output_w_init=tf.glorot_uniform_initializer(),
+                 output_w_init=tf.initializers.glorot_uniform(),
                  output_b_init=tf.zeros_initializer(),
-                 input_include_goal=False,
                  layer_normalization=False):
         super().__init__(name, env_spec)
         action_dim = env_spec.action_space.flat_dim
@@ -66,13 +64,8 @@ class ContinuousMLPPolicy(Policy):
         self._output_nonlinearity = output_nonlinearity
         self._output_w_init = output_w_init
         self._output_b_init = output_b_init
-        self._input_include_goal = input_include_goal
         self._layer_normalization = layer_normalization
-        if self._input_include_goal:
-            self.obs_dim = env_spec.observation_space.flat_dim_with_keys(
-                ['observation', 'desired_goal'])
-        else:
-            self.obs_dim = env_spec.observation_space.flat_dim
+        self._obs_dim = env_spec.observation_space.flat_dim
 
         self.model = MLPModel(output_dim=action_dim,
                               name='MLPModel',
@@ -89,15 +82,19 @@ class ContinuousMLPPolicy(Policy):
 
     def _initialize(self):
         state_input = tf.compat.v1.placeholder(tf.float32,
-                                               shape=(None, self.obs_dim))
+                                               shape=(None, self._obs_dim))
 
         with tf.compat.v1.variable_scope(self.name) as vs:
             self._variable_scope = vs
-            self.model.build(state_input)
+            outputs = self.model.build(state_input).outputs
 
         self._f_prob = tf.compat.v1.get_default_session().make_callable(
-            self.model.networks['default'].outputs,
-            feed_list=[self.model.networks['default'].input])
+            outputs, feed_list=[state_input])
+
+    @property
+    def input_dim(self):
+        """int: Dimension of the policy input."""
+        return self._obs_dim
 
     def get_action_sym(self, obs_var, name=None):
         """Symbolic graph of the action.
@@ -111,7 +108,7 @@ class ContinuousMLPPolicy(Policy):
 
         """
         with tf.compat.v1.variable_scope(self._variable_scope):
-            return self.model.build(obs_var, name=name)
+            return self.model.build(obs_var, name=name).outputs
 
     def get_action(self, observation):
         """Get single action from this policy for the input observation.
@@ -188,7 +185,6 @@ class ContinuousMLPPolicy(Policy):
                               output_nonlinearity=self._output_nonlinearity,
                               output_w_init=self._output_w_init,
                               output_b_init=self._output_b_init,
-                              input_include_goal=self._input_include_goal,
                               layer_normalization=self._layer_normalization)
 
     def __getstate__(self):
