@@ -2,7 +2,7 @@
 import tensorflow as tf
 
 from garage.tf.models import MLPMergeModel
-from garage.tf.q_functions import QFunction
+from garage.tf.q_functions.q_function import QFunction
 
 
 class ContinuousMLPQFunction(QFunction):
@@ -41,7 +41,6 @@ class ContinuousMLPQFunction(QFunction):
         output_b_init (callable): Initializer function for the bias
             of output dense layer(s). The function should return a
             tf.Tensor.
-        input_include_goal (bool): Whether input includes goal.
         layer_normalization (bool): Bool for using layer normalization.
 
     """
@@ -52,12 +51,11 @@ class ContinuousMLPQFunction(QFunction):
                  hidden_sizes=(32, 32),
                  action_merge_layer=-2,
                  hidden_nonlinearity=tf.nn.relu,
-                 hidden_w_init=tf.glorot_uniform_initializer(),
+                 hidden_w_init=tf.initializers.glorot_uniform(),
                  hidden_b_init=tf.zeros_initializer(),
                  output_nonlinearity=None,
-                 output_w_init=tf.glorot_uniform_initializer(),
+                 output_w_init=tf.initializers.glorot_uniform(),
                  output_b_init=tf.zeros_initializer(),
-                 input_include_goal=False,
                  layer_normalization=False):
         super().__init__(name)
 
@@ -70,14 +68,9 @@ class ContinuousMLPQFunction(QFunction):
         self._output_nonlinearity = output_nonlinearity
         self._output_w_init = output_w_init
         self._output_b_init = output_b_init
-        self._input_include_goal = input_include_goal
         self._layer_normalization = layer_normalization
 
-        if self._input_include_goal:
-            self._obs_dim = env_spec.observation_space.flat_dim_with_keys(
-                ['observation', 'desired_goal'])
-        else:
-            self._obs_dim = env_spec.observation_space.flat_dim
+        self._obs_dim = env_spec.observation_space.flat_dim
         self._action_dim = env_spec.action_space.flat_dim
 
         self.model = MLPMergeModel(output_dim=1,
@@ -90,6 +83,7 @@ class ContinuousMLPQFunction(QFunction):
                                    output_w_init=output_w_init,
                                    output_b_init=output_b_init,
                                    layer_normalization=layer_normalization)
+        self._network = None
 
         self._initialize()
 
@@ -102,11 +96,10 @@ class ContinuousMLPQFunction(QFunction):
 
         with tf.compat.v1.variable_scope(self.name) as vs:
             self._variable_scope = vs
-            self.model.build(obs_ph, action_ph)
+            self._network = self.model.build(obs_ph, action_ph)
 
         self._f_qval = tf.compat.v1.get_default_session().make_callable(
-            self.model.networks['default'].outputs,
-            feed_list=[obs_ph, action_ph])
+            self._network.outputs, feed_list=[obs_ph, action_ph])
 
     def get_qval(self, observation, action):
         """Q Value of the network.
@@ -129,7 +122,7 @@ class ContinuousMLPQFunction(QFunction):
             tf.Tensor: The input tensors of the model.
 
         """
-        return self.model.networks['default'].inputs
+        return self._network.inputs
 
     # pylint: disable=arguments-differ
     def get_qval_sym(self, state_input, action_input, name):
@@ -142,11 +135,12 @@ class ContinuousMLPQFunction(QFunction):
             name (str): Network variable scope.
 
         Return:
-            tf.Tensor: The output of Discrete MLP QFunction.
+            tf.Tensor: The output of Continuous MLP QFunction.
 
         """
         with tf.compat.v1.variable_scope(self._variable_scope):
-            return self.model.build(state_input, action_input, name=name)
+            return self.model.build(state_input, action_input,
+                                    name=name).outputs
 
     def clone(self, name):
         """Return a clone of the Q-function.
@@ -171,8 +165,7 @@ class ContinuousMLPQFunction(QFunction):
                               output_nonlinearity=self._output_nonlinearity,
                               output_w_init=self._output_w_init,
                               output_b_init=self._output_b_init,
-                              layer_normalization=self._layer_normalization,
-                              input_include_goal=self._input_include_goal)
+                              layer_normalization=self._layer_normalization)
 
     def __getstate__(self):
         """Object.__getstate__.
@@ -183,6 +176,7 @@ class ContinuousMLPQFunction(QFunction):
         """
         new_dict = self.__dict__.copy()
         del new_dict['_f_qval']
+        del new_dict['_network']
         return new_dict
 
     def __setstate__(self, state):
