@@ -3,11 +3,12 @@ from dowel import tabular
 import numpy as np
 import tensorflow as tf
 
+from garage import make_optimizer
 from garage.tf.misc import tensor_utils
 from garage.tf.optimizers import LbfgsOptimizer, PenaltyLbfgsOptimizer
-from garage.tf.regressors import StochasticRegressor
 from garage.tf.regressors.gaussian_cnn_regressor_model import (
     GaussianCNNRegressorModel)
+from garage.tf.regressors.regressor import StochasticRegressor
 
 
 class GaussianCNNRegressor(StochasticRegressor):
@@ -17,13 +18,11 @@ class GaussianCNNRegressor(StochasticRegressor):
         input_shape(tuple[int]): Input shape of the model (without the batch
             dimension).
         output_dim (int): Output dimension of the model.
-        filter_dims(tuple[int]): Dimension of the filters. For example,
-            (3, 5) means there are two convolutional layers. The filter
-            for first layer is of dimension (3 x 3) and the second one is of
-            dimension (5 x 5).
-        num_filters(tuple[int]): Number of filters. For example, (3, 32) means
-            there are two convolutional layers. The filter for the first layer
-            has 3 channels and the second one with 32 channels.
+        filters (Tuple[Tuple[int, Tuple[int, int]], ...]): Number and dimension
+            of filters. For example, ((3, (3, 5)), (32, (3, 3))) means there
+            are two convolutional layers. The filter for the first layer have 3
+            channels and its shape is (3 x 5), while the filter for the second
+            layer have 32 channels and its shape is (3 x 3).
         strides(tuple[int]): The stride of the sliding window. For example,
             (1, 2) means there are two convolutional layers. The stride of the
             filter for first layer is 1 and that of the second layer is 2.
@@ -64,13 +63,11 @@ class GaussianCNNRegressor(StochasticRegressor):
             deviation models share a CNN network. If True, each is a head from
             a single body network. Otherwise, the parameters are estimated
             using the outputs of two indepedent networks.
-        std_filter_dims(tuple[int]): Dimension of the filters. For example,
-            (3, 5) means there are two convolutional layers. The filter
-            for first layer is of dimension (3 x 3) and the second one is of
-            dimension (5 x 5).
-        std_num_filters(tuple[int]): Number of filters. For example, (3, 32)
+        std_filters (Tuple[Tuple[int, Tuple[int, int]], ...]): Number and
+            dimension of filters. For example, ((3, (3, 5)), (32, (3, 3)))
             means there are two convolutional layers. The filter for the first
-            layer has 3 channels and the second one with 32 channels.
+            layer have 3 channels and its shape is (3 x 5), while the filter
+            for the second layer have 32 channels and its shape is (3 x 3).
         std_strides(tuple[int]): The stride of the sliding window. For example,
             (1, 2) means there are two convolutional layers. The stride of the
             filter for first layer is 1 and that of the second layer is 2.
@@ -101,24 +98,22 @@ class GaussianCNNRegressor(StochasticRegressor):
     def __init__(self,
                  input_shape,
                  output_dim,
-                 filter_dims,
-                 num_filters,
+                 filters,
                  strides,
                  padding,
                  hidden_sizes,
                  hidden_nonlinearity=tf.nn.tanh,
-                 hidden_w_init=tf.glorot_uniform_initializer(),
+                 hidden_w_init=tf.initializers.glorot_uniform(),
                  hidden_b_init=tf.zeros_initializer(),
                  output_nonlinearity=None,
-                 output_w_init=tf.glorot_uniform_initializer(),
+                 output_w_init=tf.initializers.glorot_uniform(),
                  output_b_init=tf.zeros_initializer(),
                  name='GaussianCNNRegressor',
                  learn_std=True,
                  init_std=1.0,
                  adaptive_std=False,
                  std_share_network=False,
-                 std_filter_dims=(),
-                 std_num_filters=(),
+                 std_filters=(),
                  std_strides=(),
                  std_padding='SAME',
                  std_hidden_sizes=(),
@@ -146,18 +141,18 @@ class GaussianCNNRegressor(StochasticRegressor):
                 optimizer_args = dict()
             if optimizer is None:
                 if use_trust_region:
-                    optimizer = PenaltyLbfgsOptimizer(**optimizer_args)
+                    self._optimizer = make_optimizer(PenaltyLbfgsOptimizer,
+                                                     **optimizer_args)
                 else:
-                    optimizer = LbfgsOptimizer(**optimizer_args)
+                    self._optimizer = make_optimizer(LbfgsOptimizer,
+                                                     **optimizer_args)
             else:
-                optimizer = optimizer(**optimizer_args)
-            self._optimizer = optimizer
+                self._optimizer = make_optimizer(optimizer, **optimizer_args)
 
         self.model = GaussianCNNRegressorModel(
             input_shape=input_shape,
             output_dim=output_dim,
-            num_filters=num_filters,
-            filter_dims=filter_dims,
+            filters=filters,
             strides=strides,
             padding=padding,
             hidden_sizes=hidden_sizes,
@@ -173,8 +168,7 @@ class GaussianCNNRegressor(StochasticRegressor):
             init_std=init_std,
             min_std=None,
             max_std=None,
-            std_num_filters=std_num_filters,
-            std_filter_dims=std_filter_dims,
+            std_filters=std_filters,
             std_strides=std_strides,
             std_padding=std_padding,
             std_hidden_sizes=std_hidden_sizes,
@@ -182,6 +176,8 @@ class GaussianCNNRegressor(StochasticRegressor):
             std_output_nonlinearity=std_output_nonlinearity,
             std_parameterization='exp',
             layer_normalization=layer_normalization)
+        self._network = None
+
         self._initialize()
 
     def _initialize(self):
@@ -190,7 +186,7 @@ class GaussianCNNRegressor(StochasticRegressor):
                                              self._input_shape)
 
         with tf.compat.v1.variable_scope(self._variable_scope):
-            self.model.build(input_var)
+            self._network = self.model.build(input_var)
             ys_var = tf.compat.v1.placeholder(dtype=tf.float32,
                                               name='ys',
                                               shape=(None, self._output_dim))
@@ -203,14 +199,12 @@ class GaussianCNNRegressor(StochasticRegressor):
                 name='old_log_stds',
                 shape=(None, self._output_dim))
 
-            y_mean_var = self.model.networks['default'].y_mean
-            y_std_var = self.model.networks['default'].y_std
-            means_var = self.model.networks['default'].means
-            log_stds_var = self.model.networks['default'].log_stds
-            normalized_means_var = self.model.networks[
-                'default'].normalized_means
-            normalized_log_stds_var = self.model.networks[
-                'default'].normalized_log_stds
+            y_mean_var = self._network.y_mean
+            y_std_var = self._network.y_std
+            means_var = self._network.means
+            log_stds_var = self._network.log_stds
+            normalized_means_var = self._network.normalized_means
+            normalized_log_stds_var = self._network.normalized_log_stds
 
             normalized_ys_var = (ys_var - y_mean_var) / y_std_var
 
@@ -222,14 +216,14 @@ class GaussianCNNRegressor(StochasticRegressor):
                                              log_std=normalized_log_stds_var)
 
             mean_kl = tf.reduce_mean(
-                self.model.networks['default'].dist.kl_sym(
+                self._network.dist.kl_sym(
                     dict(mean=normalized_old_means_var,
                          log_std=normalized_old_log_stds_var),
                     normalized_dist_info_vars,
                 ))
 
             loss = -tf.reduce_mean(
-                self.model.networks['default'].dist.log_likelihood_sym(
+                self._network.dist.log_likelihood_sym(
                     normalized_ys_var, normalized_dist_info_vars))
 
             self._f_predict = tensor_utils.compile_function([input_var],
@@ -273,16 +267,12 @@ class GaussianCNNRegressor(StochasticRegressor):
 
         if self._normalize_inputs:
             # recompute normalizing constants for inputs
-            self.model.networks['default'].x_mean.load(
-                np.mean(xs, axis=0, keepdims=True))
-            self.model.networks['default'].x_std.load(
-                np.std(xs, axis=0, keepdims=True) + 1e-8)
+            self._network.x_mean.load(np.mean(xs, axis=0, keepdims=True))
+            self._network.x_std.load(np.std(xs, axis=0, keepdims=True) + 1e-8)
         if self._normalize_outputs:
             # recompute normalizing constants for outputs
-            self.model.networks['default'].y_mean.load(
-                np.mean(ys, axis=0, keepdims=True))
-            self.model.networks['default'].y_std.load(
-                np.std(ys, axis=0, keepdims=True) + 1e-8)
+            self._network.y_mean.load(np.mean(ys, axis=0, keepdims=True))
+            self._network.y_std.load(np.std(ys, axis=0, keepdims=True) + 1e-8)
         if self._use_trust_region:
             old_means, old_log_stds = self._f_pdists(xs)
             inputs = [xs, ys, old_means, old_log_stds]
@@ -326,14 +316,17 @@ class GaussianCNNRegressor(StochasticRegressor):
         means_var = params['mean']
         log_stds_var = params['log_std']
 
-        return self.model.networks[name].dist.log_likelihood_sym(
+        return self._network.dist.log_likelihood_sym(
             y_var, dict(mean=means_var, log_std=log_stds_var))
 
-    def dist_info_sym(self, x_var, name=None):
+    def dist_info_sym(self, input_var, state_info_vars=None, name=None):
         """Create a symbolic graph of the distribution parameters.
 
         Args:
-            x_var (tf.Tensor): tf.Tensor of the input data.
+            input_var (tf.Tensor): tf.Tensor of the input data.
+            state_info_vars (dict): a dictionary whose values should contain
+                information about the state of the regressor at the time it
+                received the input.
             name (str): Name of the new graph.
 
         Return:
@@ -341,27 +334,49 @@ class GaussianCNNRegressor(StochasticRegressor):
                 graph.
 
         """
+        del state_info_vars
         with tf.compat.v1.variable_scope(self._variable_scope):
-            self.model.build(x_var, name=name)
+            network = self.model.build(input_var, name=name)
 
-        means_var = self.model.networks[name].means
-        log_stds_var = self.model.networks[name].log_stds
+        means_var = network.means
+        log_stds_var = network.log_stds
 
         return dict(mean=means_var, log_std=log_stds_var)
 
-    def get_params_internal(self, **args):
-        """Get the params, which are the trainable variables."""
-        del args
-        return self._variable_scope.trainable_variables()
+    @property
+    def recurrent(self):
+        """bool: If this module has a hidden state."""
+        return False
+
+    @property
+    def vectorized(self):
+        """bool: If this module supports vectorization input."""
+        return True
+
+    @property
+    def distribution(self):
+        """garage.tf.distributions.DiagonalGaussian: Distribution."""
+        return self._network.dist
 
     def __getstate__(self):
-        """See `Object.__getstate__`."""
+        """Object.__getstate__.
+
+        Returns:
+            dict: The state to be pickled for the instance.
+
+        """
         new_dict = super().__getstate__()
         del new_dict['_f_predict']
         del new_dict['_f_pdists']
+        del new_dict['_network']
         return new_dict
 
     def __setstate__(self, state):
-        """See `Object.__setstate__`."""
+        """Object.__setstate__.
+
+        Args:
+            state (dict): Unpickled state.
+
+        """
         super().__setstate__(state)
         self._initialize()
