@@ -34,8 +34,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     @pytest.mark.large
     def test_fit_normalized(self):
         gcr = GaussianCNNRegressor(input_shape=(10, 10, 3),
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -53,22 +52,22 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
 
         prediction = gcr.predict(paths['observations'])
         average_error = 0.0
-        for i in range(len(expected)):
-            average_error += np.abs(expected[i] - prediction[i])
+        for i, exp in enumerate(expected):
+            average_error += np.abs(exp - prediction[i])
         average_error /= len(expected)
-        assert average_error <= 0.05
+        assert average_error <= 0.1
 
-        x_mean = self.sess.run(gcr.model.networks['default'].x_mean)
+        x_mean = self.sess.run(gcr.model._networks['default'].x_mean)
         x_mean_expected = np.mean(observations, axis=0, keepdims=True)
-        x_std = self.sess.run(gcr.model.networks['default'].x_std)
+        x_std = self.sess.run(gcr.model._networks['default'].x_std)
         x_std_expected = np.std(observations, axis=0, keepdims=True)
 
         assert np.allclose(x_mean, x_mean_expected)
         assert np.allclose(x_std, x_std_expected)
 
-        y_mean = self.sess.run(gcr.model.networks['default'].y_mean)
+        y_mean = self.sess.run(gcr.model._networks['default'].y_mean)
         y_mean_expected = np.mean(returns, axis=0, keepdims=True)
-        y_std = self.sess.run(gcr.model.networks['default'].y_std)
+        y_std = self.sess.run(gcr.model._networks['default'].y_std)
         y_std_expected = np.std(returns, axis=0, keepdims=True)
 
         assert np.allclose(y_mean, y_mean_expected)
@@ -77,8 +76,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     @pytest.mark.large
     def test_fit_unnormalized(self):
         gcr = GaussianCNNRegressor(input_shape=(10, 10, 3),
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -97,21 +95,21 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
 
         prediction = gcr.predict(paths['observations'])
         average_error = 0.0
-        for i in range(len(expected)):
-            average_error += np.abs(expected[i] - prediction[i])
+        for i, exp in enumerate(expected):
+            average_error += np.abs(exp - prediction[i])
         average_error /= len(expected)
         assert average_error <= 0.1
 
-        x_mean = self.sess.run(gcr.model.networks['default'].x_mean)
+        x_mean = self.sess.run(gcr.model._networks['default'].x_mean)
         x_mean_expected = np.zeros_like(x_mean)
-        x_std = self.sess.run(gcr.model.networks['default'].x_std)
+        x_std = self.sess.run(gcr.model._networks['default'].x_std)
         x_std_expected = np.ones_like(x_std)
         assert np.array_equal(x_mean, x_mean_expected)
         assert np.array_equal(x_std, x_std_expected)
 
-        y_mean = self.sess.run(gcr.model.networks['default'].y_mean)
+        y_mean = self.sess.run(gcr.model._networks['default'].y_mean)
         y_mean_expected = np.zeros_like(y_mean)
-        y_std = self.sess.run(gcr.model.networks['default'].y_std)
+        y_std = self.sess.run(gcr.model._networks['default'].y_std)
         y_std_expected = np.ones_like(y_std)
 
         assert np.allclose(y_mean, y_mean_expected)
@@ -120,8 +118,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     @pytest.mark.large
     def test_fit_smaller_subsample_factor(self):
         gcr = GaussianCNNRegressor(input_shape=(10, 10, 3),
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -138,16 +135,15 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
 
         prediction = gcr.predict(paths['observations'])
         average_error = 0.0
-        for i in range(len(expected)):
-            average_error += np.abs(expected[i] - prediction[i])
+        for i, exp in enumerate(expected):
+            average_error += np.abs(exp - prediction[i])
         average_error /= len(expected)
-        assert average_error <= 0.05
+        assert average_error <= 0.1
 
     @pytest.mark.large
     def test_fit_without_trusted_region(self):
         gcr = GaussianCNNRegressor(input_shape=(10, 10, 3),
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -164,17 +160,16 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
 
         prediction = gcr.predict(paths['observations'])
         average_error = 0.0
-        for i in range(len(expected)):
-            average_error += np.abs(expected[i] - prediction[i])
+        for i, exp in enumerate(expected):
+            average_error += np.abs(exp - prediction[i])
         average_error /= len(expected)
-        assert average_error <= 0.05
+        assert average_error <= 0.1
 
     @pytest.mark.parametrize('output_dim', [(1), (2), (3)])
     def test_log_likelihood_sym(self, output_dim):
         input_shape = (28, 28, 3)
         gcr = GaussianCNNRegressor(input_shape=input_shape,
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -200,7 +195,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
                                         new_ys_var: [label]
                                     })
         mean, log_std = gcr._f_pdists([data])
-        ll = gcr.model.networks['default'].dist.log_likelihood(
+        ll = gcr.model._networks['default'].dist.log_likelihood(
             [label], dict(mean=mean, log_std=log_std))
         assert np.allclose(ll, ll_from_sym, rtol=0, atol=1e-5)
 
@@ -210,8 +205,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     def test_optimizer_args(self, mock_lbfgs):
         lbfgs_args = dict(max_opt_itr=25)
         gcr = GaussianCNNRegressor(input_shape=(10, 10, 3),
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -227,8 +221,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     def test_is_pickleable(self):
         input_shape = (28, 28, 3)
         gcr = GaussianCNNRegressor(input_shape=input_shape,
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -253,8 +246,7 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
     def test_is_pickleable2(self):
         input_shape = (28, 28, 3)
         gcr = GaussianCNNRegressor(input_shape=input_shape,
-                                   num_filters=(3, 6),
-                                   filter_dims=(3, 3),
+                                   filters=((3, (3, 3)), (6, (3, 3))),
                                    strides=(1, 1),
                                    padding='SAME',
                                    hidden_sizes=(32, ),
@@ -266,9 +258,9 @@ class TestGaussianCNNRegressor(TfGraphTestCase):
                 'GaussianCNNRegressor/GaussianCNNRegressorModel', reuse=True):
             x_mean = tf.compat.v1.get_variable('normalized_vars/x_mean')
         x_mean.load(tf.ones_like(x_mean).eval())
-        x1 = gcr.model.networks['default'].x_mean.eval()
+        x1 = gcr.model._networks['default'].x_mean.eval()
         h = pickle.dumps(gcr)
         with tf.compat.v1.Session(graph=tf.Graph()):
             gcr_pickled = pickle.loads(h)
-            x2 = gcr_pickled.model.networks['default'].x_mean.eval()
+            x2 = gcr_pickled.model._networks['default'].x_mean.eval()
             assert np.array_equal(x1, x2)
